==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/OperationValueSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.subsystem.O_TFRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_TFRSetImpl;
import io.ciera.tool.sql.ooaofooa.value.OperationValue;
import io.ciera.tool.sql.ooaofooa.value.OperationValueSet;
import io.ciera.tool.sql.ooaofooa.value.SelectedReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.V_PARSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.SelectedReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.V_PARSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class OperationValueSetImpl extends InstanceSet<OperationValueSet,OperationValue> implements OperationValueSet {

    // attributes
    @Override
    public void setModelClassKeyLettersLineNumber( int m_modelClassKeyLettersLineNumber ) throws XtumlException {
        for ( OperationValue operationvalue : this ) operationvalue.setModelClassKeyLettersLineNumber( m_modelClassKeyLettersLineNumber );
    }
    @Override
    public void setTfr_ID( UniqueId ref_Tfr_ID ) throws XtumlException {
        for ( OperationValue operationvalue : this ) operationvalue.setTfr_ID( ref_Tfr_ID );
    }
    @Override
    public void setParmListOK( boolean m_ParmListOK ) throws XtumlException {
        for ( OperationValue operationvalue : this ) operationvalue.setParmListOK( m_ParmListOK );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( OperationValue operationvalue : this ) operationvalue.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setModelClassKeyLettersColumn( int m_modelClassKeyLettersColumn ) throws XtumlException {
        for ( OperationValue operationvalue : this ) operationvalue.setModelClassKeyLettersColumn( m_modelClassKeyLettersColumn );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( OperationValue operationvalue : this ) operationvalue.setVar_ID( ref_Var_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( OperationValue operationvalue : this ) valueset.add( operationvalue.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public V_PARSet R811_has_V_PAR() throws XtumlException {
        V_PARSet v_parset = new V_PARSetImpl();
        for ( OperationValue operationvalue : this ) v_parset.addAll( operationvalue.R811_has_V_PAR() );
        return v_parset;
    }
    @Override
    public SelectedReferenceSet R825_SelectedReference() throws XtumlException {
        SelectedReferenceSet selectedreferenceset = new SelectedReferenceSetImpl();
        for ( OperationValue operationvalue : this ) selectedreferenceset.add( operationvalue.R825_SelectedReference() );
        return selectedreferenceset;
    }
    @Override
    public O_TFRSet R829_O_TFR() throws XtumlException {
        O_TFRSet o_tfrset = new O_TFRSetImpl();
        for ( OperationValue operationvalue : this ) o_tfrset.add( operationvalue.R829_O_TFR() );
        return o_tfrset;
    }
    @Override
    public V_VARSet R830_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( OperationValue operationvalue : this ) v_varset.add( operationvalue.R830_V_VAR() );
        return v_varset;
    }


    @Override
    public OperationValue nullElement() {
        return OperationValueImpl.EMPTY_OPERATIONVALUE;
    }

    @Override
    public OperationValueSet emptySet() {
      return new OperationValueSetImpl();
    }

    @Override
    public OperationValueSet value() {
        return this;
    }

    @Override
    public List<OperationValue> elements() {
        return Arrays.asList(toArray(new OperationValue[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/OperationValueSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.subsystem.O_TFRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_TFRSetImpl;
import io.ciera.tool.sql.ooaofooa.value.OperationValue;
import io.ciera.tool.sql.ooaofooa.value.OperationValueSet;
import io.ciera.tool.sql.ooaofooa.value.SelectedReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.V_PARSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.SelectedReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.V_PARSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class OperationValueSetImpl extends InstanceSet<OperationValueSet,OperationValue> implements OperationValueSet {

    public OperationValueSetImpl() {
    }

    public OperationValueSetImpl(Comparator<? super OperationValue> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( OperationValue operationvalue : this ) operationvalue.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setModelClassKeyLettersLineNumber( int m_modelClassKeyLettersLineNumber ) throws XtumlException {
        for ( OperationValue operationvalue : this ) operationvalue.setModelClassKeyLettersLineNumber( m_modelClassKeyLettersLineNumber );
    }
    @Override
    public void setParmListOK( boolean m_ParmListOK ) throws XtumlException {
        for ( OperationValue operationvalue : this ) operationvalue.setParmListOK( m_ParmListOK );
    }
    @Override
    public void setTfr_ID( UniqueId ref_Tfr_ID ) throws XtumlException {
        for ( OperationValue operationvalue : this ) operationvalue.setTfr_ID( ref_Tfr_ID );
    }
    @Override
    public void setModelClassKeyLettersColumn( int m_modelClassKeyLettersColumn ) throws XtumlException {
        for ( OperationValue operationvalue : this ) operationvalue.setModelClassKeyLettersColumn( m_modelClassKeyLettersColumn );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( OperationValue operationvalue : this ) operationvalue.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( OperationValue operationvalue : this ) valueset.add( operationvalue.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public V_PARSet R811_has_V_PAR() throws XtumlException {
        V_PARSet v_parset = new V_PARSetImpl();
        for ( OperationValue operationvalue : this ) v_parset.addAll( operationvalue.R811_has_V_PAR() );
        return v_parset;
    }
    @Override
    public SelectedReferenceSet R825_SelectedReference() throws XtumlException {
        SelectedReferenceSet selectedreferenceset = new SelectedReferenceSetImpl();
        for ( OperationValue operationvalue : this ) selectedreferenceset.add( operationvalue.R825_SelectedReference() );
        return selectedreferenceset;
    }
    @Override
    public O_TFRSet R829_O_TFR() throws XtumlException {
        O_TFRSet o_tfrset = new O_TFRSetImpl();
        for ( OperationValue operationvalue : this ) o_tfrset.add( operationvalue.R829_O_TFR() );
        return o_tfrset;
    }
    @Override
    public V_VARSet R830_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( OperationValue operationvalue : this ) v_varset.add( operationvalue.R830_V_VAR() );
        return v_varset;
    }


    @Override
    public OperationValue nullElement() {
        return OperationValueImpl.EMPTY_OPERATIONVALUE;
    }

    @Override
    public OperationValueSet emptySet() {
      return new OperationValueSetImpl();
    }

    @Override
    public OperationValueSet emptySet(Comparator<? super OperationValue> comp) {
      return new OperationValueSetImpl(comp);
    }

    @Override
    public OperationValueSet value() {
        return this;
    }

    @Override
    public List<OperationValue> elements() {
        return Arrays.asList(toArray(new OperationValue[0]));
    }

}
